@@ -1,6 +1,7 @@
 import click
-import typer
-from typer.testing import CliRunner, columns_match
+
+import typer_cloup as typer
+from typer_cloup.testing import CliRunner, columns_match
 
 runner = CliRunner()
 
